@@ -236,7 +236,7 @@ class BuildStorage(object):
 
     def __iter__(self):
         ini = self._get_ini_with_lock()
-        return iter([x.encode(UTF8) for x in ini if x != 'DEFAULT'])
+        return iter(sorted([x.encode(UTF8) for x in ini if x != 'DEFAULT']))
 
     def clear_unmounted(self):
         """
